16.127. cdist-type__postgres_database(7) — cdist 6.9.4 documentation

# 16.127. cdist-type__postgres_database(7)

## 16.127.1. NAME

cdist-type__postgres_database - Create/drop postgres databases

## 16.127.2. DESCRIPTION

This cdist type allows you to create or drop postgres databases.

## 16.127.3. OPTIONAL PARAMETERS

state

  Either 'present' or 'absent', defaults to 'present'.

owner

  Specifies the database user who will own the new database.

encoding

  Specifies the character encoding scheme to be used in this database.

lc-collate

  Specifies the LC_COLLATE setting to be used in this database.

lc-ctype

  Specifies the LC_CTYPE setting to be used in this database.

template

  Specifies the template database from which to build this database.

## 16.127.4. EXAMPLES

    __postgres_database mydbname --owner mydbusername

## 16.127.5. SEE ALSO

cdist-type__postgres_role(7)

## 16.127.6. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 16.127.7. COPYING

Copyright (C) 2011 Steven Armstrong. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.